@@ -1,10 +1,15 @@
 __author__ = "Minos Framework Devs"
 __email__ = "hey@minos.run"
-__version__ = "0.5.1"
+__version__ = "0.6.0"
 
+from .common import (
+    KafkaBrokerBuilderMixin,
+    KafkaCircuitBreakerMixin,
+)
 from .publisher import (
     InMemoryQueuedKafkaBrokerPublisher,
     KafkaBrokerPublisher,
+    KafkaBrokerPublisherBuilder,
     PostgreSqlQueuedKafkaBrokerPublisher,
 )
 from .subscriber import (
